:mod:`errors` -- Exceptions raised by the :mod:`mongolabclient` package
-----------------------------------------------------------------------

.. automodule:: mongolabclient.errors
    :synopsis: Exceptions raised by the mongolabclient package
    :members:
    :undoc-members:
    :show-inheritance:
